@@ -18,7 +18,7 @@ Rcpp::CharacterVector rxQs(SEXP const x) {
   Rcpp::Function qserialize = Rcpp::as<Rcpp::Function>(qsNs["qserialize"]);
   return base91_encode(qserialize(x, Rcpp::CharacterVector::create("high"), Rcpp::CharacterVector::create("zstd"),
 				    Rcpp::IntegerVector::create(22),
-				    Rcpp::IntegerVector::create(15), Rcpp::LogicalVector::create(false)));
+				    Rcpp::IntegerVector::create(15), Rcpp::LogicalVector::create(true)));
 }
 
 //[[Rcpp::export]]
@@ -26,5 +26,5 @@ SEXP rxQr(const std::string& encoded_string) {
   loadQs();
   Rcpp::Function base91_decode = Rcpp::as<Rcpp::Function>(qsNs["base91_decode"]);
   Rcpp::Function qdeserialize = Rcpp::as<Rcpp::Function>(qsNs["qdeserialize"]);
-  return qdeserialize(base91_decode(Rcpp::wrap(encoded_string)), true, false);
+  return qdeserialize(base91_decode(Rcpp::wrap(encoded_string)), false, false);
 }
